@@ -9,8 +9,21 @@ from pathlib import Path
 from rasterio._base import gdal_version
 from rasterio.drivers import driver_from_extension, is_blacklisted
 from rasterio.dtypes import (
-    bool_, ubyte, sbyte, uint8, int8, uint16, int16, uint32, int32, float32, float64,
-    complex_, check_dtype)
+    bool_,
+    ubyte,
+    sbyte,
+    uint8,
+    int8,
+    uint16,
+    int16,
+    uint32,
+    int32,
+    float32,
+    float64,
+    complex_,
+    complex_int16,
+    check_dtype,
+)
 from rasterio.env import ensure_env_with_credentials, Env
 from rasterio.errors import RasterioIOError, DriverCapabilityError
 from rasterio.io import (
@@ -27,7 +40,7 @@ import rasterio.enums
 import rasterio.path
 
 __all__ = ['band', 'open', 'pad', 'Env']
-__version__ = "1.2.2"
+__version__ = "1.2.6"
 __gdal_version__ = gdal_version()
 
 # Rasterio attaches NullHandler to the 'rasterio' logger and its
